| compute_ci.penalized_spline_model | R Documentation |
Compute confidence interval for penalized_spline_model
compute_ci.penalized_spline_model(x, ci = 0.95, ...)
x |
- serosv models |
ci |
- confidence interval |
... |
- arbitrary arguments |
list of confidence interval for seroprevalence and foi Each confidence interval dataframe with 4 variables, x and y for the fitted values and ymin and ymax for the confidence interval
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.